UsfmPassage class

Constructors

UsfmPassage(List<UsfmParagraph> paragraphs)

Properties

hashCode int
The hash code for this object.
no setterinherited
paragraphs List<UsfmParagraph>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wordsOfJesusIds Set<int>
no setter

Methods

append(List<ParagraphElement> elements, ParagraphFormat format, {Set<int>? wordsOfJesusIds}) → void
commit([List<ParagraphElement>? elements, ParagraphFormat? format, Set<int>? wordsOfJesusIds]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited